# See end of file for license and copyright information
package Foswiki::Plugins::JQTablePlugin;

use warnings;
use strict;
use Assert;

use Foswiki::Func                  ();    # The plugins API
use Foswiki::Plugins               ();    # For the API version
use Foswiki::Plugins::JQueryPlugin ();

our $VERSION = '1.15';
our $RELEASE = '25 Apr 2017';
our $SHORTDESCRIPTION =
  'Javascript implementation of the classic TablePlugin, using JQuery';
our $NO_PREFS_IN_TOPIC = 1;
our $DEFAULT_TABLE_SETTINGS =
'tableborder="1" valign="top" headercolor="#fff" headerbg="#687684" headerbgsorted="#345" databg="#fff,#edf4f9" databgsorted="#f1f7fc,#ddebf6" tablerules="rows" headerrules="cols"';
our %pluginAttributes;

sub initPlugin {
    my ( $topic, $web, $user, $installWeb ) = @_;

    Foswiki::Plugins::JQueryPlugin::registerPlugin( 'tablesorter',
        'Foswiki::Plugins::JQTablePlugin::TableSorter' );

    my $sort = Foswiki::Func::getPreferencesValue('TABLEPLUGIN_SORT');
    $sort = 'all' unless defined $sort;

    if ( $sort =~ /^(all|attachments)/ ) {

        # In this special case, the tablesorter is always required
        Foswiki::Plugins::JQueryPlugin::createPlugin('tablesorter');
        Foswiki::Func::addToZone( 'script', 'JQTABLEPLUGIN::SORT',
            <<HERE, 'JQUERYPLUGIN::FOSWIKI::PREFERENCES' );
<script type='text/javascript'>
jQuery.extend(foswiki.preferences, {
  'JQTablePlugin.sort' : '$sort'
});
</script>
HERE
    }

    # if the TablePlugin isn't there to handle table formatting, then
    # enable JS to do it.
    if ( !$Foswiki::cfg{Plugins}{TablePlugin}{Enabled} ) {
        Foswiki::Func::registerTagHandler( 'TABLE', \&_TABLE );
    }
    return 1;
}

sub _TABLE {
    my ( $session, $params, $topic, $web ) = @_;

    Foswiki::Plugins::JQueryPlugin::createPlugin('tablesorter');

    _readPluginSettings() if !%pluginAttributes;
    my %p = %pluginAttributes;
    while ( my ( $k, $v ) = each %$params ) {
        next if $k =~ /^_/ && $k ne '_DEFAULT';
        $p{$k} = $v;
    }

    my @htmlData = ();
    foreach my $key ( keys %p ) {
        push @htmlData, "data-" . $key . "='" . $p{$key} . "'";
    }
    return
        "<div class='jqtp_process' style='display:none' "
      . join( " ", @htmlData )
      . "></div>";
}

# Copied from TablePlugin
sub _readPluginSettings {

    my $configureAttrStr =
      $Foswiki::cfg{Plugins}{TablePlugin}{DefaultAttributes};

    my $pluginAttrStr =
      Foswiki::Func::getPreferencesValue('TABLEPLUGIN_TABLEATTRIBUTES');

    $configureAttrStr = $DEFAULT_TABLE_SETTINGS
      unless defined $configureAttrStr;

    $configureAttrStr = Foswiki::Func::expandCommonVariables($configureAttrStr)
      if $configureAttrStr;

    $pluginAttrStr = Foswiki::Func::expandCommonVariables($pluginAttrStr)
      if $pluginAttrStr;

    my %configureParams = Foswiki::Func::extractParameters($configureAttrStr);
    my %pluginParams    = Foswiki::Func::extractParameters($pluginAttrStr);

    %pluginAttributes = ( %configureParams, %pluginParams );
}

1;
__END__
Plugin for Foswiki - The Free and Open Source Wiki, http://foswiki.org/

JQTablePlugin is copyright (C) Crawford Currie http://c-dot.co.uk

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

For licensing info read LICENSE file in the root of this distribution.
